@@ -11,7 +11,8 @@ class Store(StoreInterface):
 
     @cached
     def read_secret(self, secret):
-        if res := os.getenv(secret):
+        res = os.getenv(secret)
+        if res:
             return res
         else:
             raise Exception(f"Secret '{secret}' not found in store '{self.name}'")
